@@ -12,7 +12,7 @@ from typing import (
     Union,
 )
 
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, Field, validator
 
 from datamodel_code_generator import snooper_to_methods
 from datamodel_code_generator.format import PythonVersion
@@ -42,6 +42,7 @@ json_schema_data_formats: Dict[str, Dict[str, Types]] = {
     'number': {
         'float': Types.float,
         'double': Types.double,
+        'decimal': Types.decimal,
         'time': Types.time,
         'default': Types.number,
     },
@@ -60,8 +61,10 @@ json_schema_data_formats: Dict[str, Dict[str, Types]] = {
         'uuid4': Types.uuid4,
         'uuid5': Types.uuid5,
         'uri': Types.uri,
+        'hostname': Types.hostname,
         'ipv4': Types.ipv4,
         'ipv6': Types.ipv6,
+        'decimal': Types.decimal,
     },
     'boolean': {'default': Types.boolean},
     'object': {'default': Types.object},
@@ -83,6 +86,7 @@ class JsonSchemaObject(BaseModel):
     exclusiveMaximum: Optional[bool]
     exclusiveMinimum: Optional[bool]
     additionalProperties: Union['JsonSchemaObject', bool, None]
+    oneOf: List['JsonSchemaObject'] = []
     anyOf: List['JsonSchemaObject'] = []
     allOf: List['JsonSchemaObject'] = []
     enum: List[str] = []
@@ -110,6 +114,12 @@ class JsonSchemaObject(BaseModel):
     def ref_object_name(self) -> str:
         return self.ref.rsplit('/', 1)[-1]  # type: ignore
 
+    @validator('items', pre=True)
+    def validate_items(cls, values: Any) -> Any:
+        if not values:  # this condition expects empty dict
+            return None
+        return values
+
 
 JsonSchemaObject.update_forward_refs()
 
@@ -188,46 +198,53 @@ class JsonSchemaParser(Parser):
 
         self.extra_template_data[name]['title'] = obj.title
 
-    def parse_any_of(self, name: str, obj: JsonSchemaObject) -> List[DataType]:
-        any_of_data_types: List[DataType] = []
-        for any_of_item in obj.anyOf:
-            if any_of_item.ref:  # $ref
-                any_of_data_types.append(
+    def parse_list_item(
+        self, name: str, target_items: List[JsonSchemaObject]
+    ) -> List[DataType]:
+        data_types: List[DataType] = []
+        for item in target_items:
+            if item.ref:  # $ref
+                data_types.append(
                     self.data_type(
-                        type=self.get_class_name(
-                            any_of_item.ref_object_name, unique=False
-                        ),
+                        type=self.get_class_name(item.ref_object_name, unique=False),
                         ref=True,
                         version_compatible=True,
                     )
                 )
-            elif not any(v for k, v in vars(any_of_item).items() if k != 'type'):
+            elif not any(v for k, v in vars(item).items() if k != 'type'):
                 # trivial types
-                any_of_data_types.extend(self.get_data_type(any_of_item))
+                data_types.extend(self.get_data_type(item))
             elif (
-                any_of_item.is_array
-                and isinstance(any_of_item.items, JsonSchemaObject)
-                and not any(
-                    v for k, v in vars(any_of_item.items).items() if k != 'type'
-                )
+                item.is_array
+                and isinstance(item.items, JsonSchemaObject)
+                and not any(v for k, v in vars(item.items).items() if k != 'type')
             ):
                 # trivial item types
-                any_of_data_types.append(
+                types = [t.type_hint for t in self.get_data_type(item.items)]
+                data_types.append(
                     self.data_type(
-                        type=f"List[{', '.join([t.type_hint for t in self.get_data_type(any_of_item.items)])}]",
+                        type=f"List[Union[{', '.join(types)}]]"
+                        if len(types) > 1
+                        else f"List[{types[0]}]",
                         imports_=[Import(from_='typing', import_='List')],
                     )
                 )
             else:
                 name = self.get_class_name(name, unique=False)
                 singular_name = get_singular_name(name)
-                self.parse_object(singular_name, any_of_item)
-                any_of_data_types.append(
+                self.parse_object(singular_name, item)
+                data_types.append(
                     self.data_type(
                         type=singular_name, ref=True, version_compatible=True
                     )
                 )
-        return any_of_data_types
+        return data_types
+
+    def parse_any_of(self, name: str, obj: JsonSchemaObject) -> List[DataType]:
+        return self.parse_list_item(name, obj.anyOf)
+
+    def parse_one_of(self, name: str, obj: JsonSchemaObject) -> List[DataType]:
+        return self.parse_list_item(name, obj.oneOf)
 
     def parse_all_of(self, name: str, obj: JsonSchemaObject) -> List[DataType]:
         fields: List[DataModelFieldBase] = []
@@ -272,7 +289,8 @@ class JsonSchemaParser(Parser):
         fields: List[DataModelFieldBase] = []
 
         for field_name, field in properties.items():
-            is_list = False
+            is_list: bool = False
+            is_union: bool = False
             field_types: List[DataType]
             field_name, alias = get_valid_field_name_and_alias(field_name)
             if field.ref:
@@ -290,8 +308,11 @@ class JsonSchemaParser(Parser):
                 )
                 field_types = array_fields[0].data_types
                 is_list = True
+                is_union = True
             elif field.anyOf:
                 field_types = self.parse_any_of(field_name, field)
+            elif field.oneOf:
+                field_types = self.parse_one_of(field_name, field)
             elif field.allOf:
                 class_name = self.get_class_name(field_name)
                 field_types = self.parse_all_of(class_name, field)
@@ -332,6 +353,7 @@ class JsonSchemaParser(Parser):
                     data_types=field_types,
                     required=required,
                     is_list=is_list,
+                    is_union=is_union,
                     alias=alias,
                 )
             )
@@ -355,7 +377,7 @@ class JsonSchemaParser(Parser):
         self, name: str, obj: JsonSchemaObject
     ) -> Tuple[List[DataModelFieldBase], List[DataType]]:
         if isinstance(obj.items, JsonSchemaObject):
-            items: List[JsonSchemaObject] = [obj.items]
+            items = [obj.items]
         else:
             items = obj.items or []
         item_obj_data_types: List[DataType] = []
@@ -383,6 +405,13 @@ class JsonSchemaParser(Parser):
             elif item.allOf:
                 singular_name = get_singular_name(name)
                 item_obj_data_types.extend(self.parse_all_of(singular_name, item))
+            elif item.enum:
+                singular_name = get_singular_name(name, 'Enum')
+                enum = self.parse_enum(singular_name, item)
+                item_obj_data_types.append(
+                    self.data_type(type=enum.name, ref=True, version_compatible=True)
+                )
+
             else:
                 item_obj_data_types.extend(self.get_data_type(item))
 
